# BeaconTau

A BEACON data analysis package for python3.

This package uses [pybind11](https://github.com/pybind/pybind11) to get the raw c-structs from [the BEACON fork of libnuphase](https://github.com/beaconTau/libnuphase) into python.
From there all the standard python loveliness is available.

## Flame (Facility for Live Action Monitoring of Events)

A prototype online browser based event on BeaconTau and bokeh.

## Version history

I'm aiming to keep [libnuphase](https://github.com/beaconTau/libnuphase) version tags in sync with BeaconTau version tags.

| Version | Notes                                               |
|---------|-----------------------------------------------------|
| 0.1.1   | Working local implementation of BeaconTau and Flame |



